These functios are default predict functions. Each function returns a single numeric score for each new observation. Those functions are very important since informations from many models have to be extracted with various techniques.
# S3 method for WrappedModel
yhat(X.model, newdata, ...)# S3 method for H2ORegressionModel
yhat(X.model, newdata, ...)
# S3 method for H2OBinomialModel
yhat(X.model, newdata, ...)
# S3 method for scikitlearn_model
yhat(X.model, newdata, ...)
# S3 method for keras
yhat(X.model, newdata, ...)
# S3 method for mljar_model
yhat(X.model, newdata, ...)
object - a model to be explained
data.frame or matrix - observations for prediction
other parameters that will be passed to the predict function
An numeric vector of predictions
Currently supported packages are:
`mlr` see more in explain_mlr
`h2o` see more in explain_h2o
`scikit-learn` see more in explain_scikitlearn
`keras` see more in explain_keras
`mljar` see more in explain_mljar